/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_hjn7rgUF);
  numBytes += sLine_init(&sLine_l3G98zDC);
  numBytes += sTabhead_init(&sTabhead_ohd4nWbZ, &hTable_p4iHiZ2o);
  numBytes += sTabread_init(&sTabread_mVwqd7El, &hTable_p4iHiZ2o, false);
  numBytes += sTabread_init(&sTabread_fbq0hCMJ, &hTable_p4iHiZ2o, false);
  numBytes += sLine_init(&sLine_J80AX6Uy);
  numBytes += sLine_init(&sLine_ySWsSxGi);
  numBytes += sLine_init(&sLine_8RbaKBNP);
  numBytes += sTabhead_init(&sTabhead_EuhNEfv8, &hTable_IJ3t6TuL);
  numBytes += sTabread_init(&sTabread_WRto2vL2, &hTable_IJ3t6TuL, false);
  numBytes += sTabread_init(&sTabread_aq1IkHN9, &hTable_IJ3t6TuL, false);
  numBytes += sLine_init(&sLine_RzzPelBD);
  numBytes += sTabwrite_init(&sTabwrite_7SnxC9Tf, &hTable_p4iHiZ2o);
  numBytes += sTabwrite_init(&sTabwrite_VwLxucoN, &hTable_IJ3t6TuL);
  numBytes += sRPole_init(&sRPole_s1jK79zH);
  numBytes += sRPole_init(&sRPole_ayi4HAxi);
  numBytes += sRPole_init(&sRPole_276uF66i);
  numBytes += sDel1_init(&sDel1_2YNvZGkb);
  numBytes += sLine_init(&sLine_mAGaG013);
  numBytes += sLine_init(&sLine_59fuyhND);
  numBytes += sRPole_init(&sRPole_noRB4NxI);
  numBytes += sRPole_init(&sRPole_lK3F8PJD);
  numBytes += sRPole_init(&sRPole_szo2iTR9);
  numBytes += sDel1_init(&sDel1_u0xBiZke);
  numBytes += sLine_init(&sLine_0mrRf87m);
  numBytes += sLine_init(&sLine_c64T5Ws9);
  numBytes += sLine_init(&sLine_PDtuFEeu);
  numBytes += sLine_init(&sLine_gDwKpKk9);
  numBytes += cVar_init_f(&cVar_yUU7fBZ6, 0.0f);
  numBytes += cVar_init_f(&cVar_zjx8Mk4P, 0.0f);
  numBytes += cVar_init_f(&cVar_JNGZBgOC, 0.0f);
  numBytes += cVar_init_f(&cVar_dtcbEIVJ, 0.0f);
  numBytes += cSlice_init(&cSlice_3uAbmTV1, 1, -1);
  numBytes += cVar_init_f(&cVar_4kT9rPqR, 0.5f);
  numBytes += cSlice_init(&cSlice_d99uSVrb, 1, -1);
  numBytes += cVar_init_f(&cVar_taEwSAR8, 0.2f);
  numBytes += cSlice_init(&cSlice_AHNEiIiZ, 1, -1);
  numBytes += cVar_init_f(&cVar_4P7WSNZm, 500.0f);
  numBytes += cSlice_init(&cSlice_4ENVzwiO, 1, -1);
  numBytes += cVar_init_f(&cVar_qn3lBel5, 0.25f);
  numBytes += cDelay_init(this, &cDelay_tGYWYeWo, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VqCpZ0KV, 0.0f);
  numBytes += hTable_init(&hTable_p4iHiZ2o, 256);
  numBytes += cDelay_init(this, &cDelay_vE14V7M6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_B0qMNFh7, 0.0f);
  numBytes += hTable_init(&hTable_IJ3t6TuL, 256);
  numBytes += cVar_init_f(&cVar_ZazRoCSy, 8000.0f);
  numBytes += cBinop_init(&cBinop_1qQqz5vR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JQT9YG8i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hBqVWXQy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_sF4r6GdH, 8000.0f);
  numBytes += cBinop_init(&cBinop_rMRAK0eD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bs8Goliy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jKMgk0Pz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EsDjvHxw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IOnFPqGx, 300.0f);
  numBytes += cBinop_init(&cBinop_6Z9mj4Q3, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_UO3RqxHn, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_ZczcmHP2, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_d1zZdoBB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TVxssTIG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iRW3LZbH, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_5i9CPP9R, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_uQvOSfCI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ydeartJN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kKZm2kt4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZBYHNm81, 8000.0f);
  numBytes += cBinop_init(&cBinop_qzC1uMkg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QLbquDv6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L52Uz3qS, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KgKEGpDp, 8000.0f);
  numBytes += cBinop_init(&cBinop_GoidQ0ll, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_yOfxnnr4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y0H5VaYA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y47bT1Dn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IJ3pbPW9, 300.0f);
  numBytes += cBinop_init(&cBinop_xZg6GTcs, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_wXUpDpJV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_11HUoNk4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gX4iSwbg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vWghqqlp, 1.0f);
  numBytes += cIf_init(&cIf_oofkThFd, false);
  numBytes += cIf_init(&cIf_3iRsHI3l, false);
  numBytes += cVar_init_f(&cVar_tXC6ekTC, 0.0f);
  numBytes += cVar_init_f(&cVar_j6B4xmOE, 0.0f);
  numBytes += cVar_init_f(&cVar_tGKhVlpm, 60000.0f);
  numBytes += cVar_init_f(&cVar_8Za4uPpW, 500.0f);
  numBytes += cSlice_init(&cSlice_vTFpLFNj, 1, -1);
  numBytes += cSlice_init(&cSlice_4ETKl86C, 1, -1);
  numBytes += cVar_init_f(&cVar_mW28HXz1, 0.0f);
  numBytes += cIf_init(&cIf_pOyo1WRh, false);
  numBytes += cBinop_init(&cBinop_VLK2Hi8q, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_pWxM1GeC, 120.0f);
  numBytes += cBinop_init(&cBinop_VHXkuSZ8, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_q6gsXAeN, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_p4iHiZ2o);
  hTable_free(&hTable_IJ3t6TuL);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_p4iHiZ2o; // del-1011-delayL
    case 0xF057CB49: return &hTable_IJ3t6TuL; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cnBMsFnH_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BJCfu9uW_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jrr8r5C1_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tn2jKWGP_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ceir25yS_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U5TWXn7K_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7504E8G7_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BA3eYIue_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wkAehL63_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qFRVqrcq_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sfmXnjQ6_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YyPzAwrG_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_yUU7fBZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yJKT3QQD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_zjx8Mk4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_siiB8jq4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_JNGZBgOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WD2KNftw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_dtcbEIVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SIOTDAMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_itWNQMrt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3uAbmTV1, 0, m, &cSlice_3uAbmTV1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_3uAbmTV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3IhSMKW2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3IhSMKW2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_4kT9rPqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3IhSMKW2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_3IhSMKW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wkAehL63_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_E5FKoG2B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_d99uSVrb, 0, m, &cSlice_d99uSVrb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_o7TEUdTt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_d99uSVrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oy9WvWgg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oy9WvWgg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_taEwSAR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oy9WvWgg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_oy9WvWgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7504E8G7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_ZV0FZbDa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AHNEiIiZ, 0, m, &cSlice_AHNEiIiZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_itWNQMrt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_AHNEiIiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XVpYyRbk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XVpYyRbk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_4P7WSNZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XVpYyRbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_XVpYyRbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qFRVqrcq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_yijDsKfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Olixbn8K_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Olixbn8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ULSTQEIW_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_9DNJr2vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F6xEQwpk_sendMessage(_c, 0, m);
  cMsg_sawggyIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_3jWcJ9Te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QMHxhQco_sendMessage(_c, 0, m);
  cMsg_Yn5FBTKL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ULSTQEIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yihntFjy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yihntFjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XTBrUtZj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_89jlauFb_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_89jlauFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ClLlSKpD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_XTBrUtZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UmY7qXgO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_UmY7qXgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9DM8ZQLp_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ClLlSKpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EobqLmKC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_EobqLmKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AbT35NSi_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9DM8ZQLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_9DNJr2vE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_AbT35NSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3jWcJ9Te_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sX2GswNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HXvudGpX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HXvudGpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3fIQhqA9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3fIQhqA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JQIcyFWn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JQIcyFWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JXin1KE6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yiHq8r2g_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JXin1KE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xcVre4RK_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_yiHq8r2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TrydeJvG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_xcVre4RK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5OGvp0Ui_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TrydeJvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HjoARtvJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HjoARtvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EVwYMesT_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_EVwYMesT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DNCHdZKE_sendMessage(_c, 0, m);
  cMsg_uOetnZR8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_5OGvp0Ui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_US2OtYXp_sendMessage(_c, 0, m);
  cMsg_7X9VOOJo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_o7TEUdTt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4ENVzwiO, 0, m, &cSlice_4ENVzwiO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZV0FZbDa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_4ENVzwiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tlGoLOz0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tlGoLOz0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_qn3lBel5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tlGoLOz0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_tlGoLOz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BA3eYIue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_LHW4gAky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YvZkDLL1_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_YvZkDLL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Q0whguEV_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_tGYWYeWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tGYWYeWo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VqCpZ0KV, 0, m, &cDelay_VqCpZ0KV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGYWYeWo, 0, m, &cDelay_tGYWYeWo_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7SnxC9Tf, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_VqCpZ0KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VqCpZ0KV, m);
  cMsg_dCSTkk8a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_wYWvfadb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fDTHXcqN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_bG1tLDU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KKyiVJI2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_p4iHiZ2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b6q9ZfCy_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGYWYeWo, 2, m, &cDelay_tGYWYeWo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Nyaew0Mg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_KKyiVJI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_p4iHiZ2o, 0, m, &hTable_p4iHiZ2o_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Q0whguEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_bG1tLDU7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_dCSTkk8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_p4iHiZ2o, 0, m, &hTable_p4iHiZ2o_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Nyaew0Mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGYWYeWo, 0, m, &cDelay_tGYWYeWo_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_b6q9ZfCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VqCpZ0KV, 2, m, &cDelay_VqCpZ0KV_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fDTHXcqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7SnxC9Tf, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_HQH1shtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HtaJKgzW_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_HtaJKgzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XMMJ7tys_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_vE14V7M6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vE14V7M6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B0qMNFh7, 0, m, &cDelay_B0qMNFh7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vE14V7M6, 0, m, &cDelay_vE14V7M6_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VwLxucoN, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_B0qMNFh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B0qMNFh7, m);
  cMsg_vpuuRYbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_28EwNnXi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_CCHf3dDh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_2fYW2b5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hQgOCEs8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_IJ3t6TuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7bBALs6a_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vE14V7M6, 2, m, &cDelay_vE14V7M6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VxQLbKIz_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_hQgOCEs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_IJ3t6TuL, 0, m, &hTable_IJ3t6TuL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XMMJ7tys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_2fYW2b5A_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_vpuuRYbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_IJ3t6TuL, 0, m, &hTable_IJ3t6TuL_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_VxQLbKIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vE14V7M6, 0, m, &cDelay_vE14V7M6_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_7bBALs6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_B0qMNFh7, 2, m, &cDelay_B0qMNFh7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_CCHf3dDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VwLxucoN, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_ZazRoCSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1qQqz5vR, HV_BINOP_MULTIPLY, 0, m, &cBinop_1qQqz5vR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZfDSug06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l2yD2UsX_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_l2yD2UsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s4VdtDwH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_1qQqz5vR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZMFceQB4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_u93SHa6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1qQqz5vR, HV_BINOP_MULTIPLY, 1, m, &cBinop_1qQqz5vR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_s4VdtDwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u93SHa6T_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZMFceQB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UKJH3Pnp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_UKJH3Pnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9gj5OuoM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hBqVWXQy, m);
}

void Heavy_WSTD_DLAY::cBinop_9gj5OuoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JQT9YG8i, m);
}

void Heavy_WSTD_DLAY::cVar_sF4r6GdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rMRAK0eD, HV_BINOP_MULTIPLY, 0, m, &cBinop_rMRAK0eD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_yu5l5ayQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DVNVDyUC_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_DVNVDyUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mPIhQo8D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_rMRAK0eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Xip2GUec_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dsUuSXMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rMRAK0eD, HV_BINOP_MULTIPLY, 1, m, &cBinop_rMRAK0eD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mPIhQo8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dsUuSXMP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Xip2GUec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ogT564yX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ogT564yX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QWYLxhQw_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jKMgk0Pz, m);
}

void Heavy_WSTD_DLAY::cBinop_QWYLxhQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bs8Goliy, m);
}

void Heavy_WSTD_DLAY::cBinop_9xU83vxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fuSpLOlu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fuSpLOlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1HYdndZx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J0nxmXb8_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_IOnFPqGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_QMJhPL8a_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lSjpFpSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VSMxaiJq_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_VSMxaiJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Z9mj4Q3, HV_BINOP_DIVIDE, 1, m, &cBinop_6Z9mj4Q3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1HYdndZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fDfDhlOf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fDfDhlOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UO3RqxHn, m);
}

void Heavy_WSTD_DLAY::cMsg_VJ6gyvSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HQPcqtBZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HQPcqtBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9xU83vxV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_J0nxmXb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EsDjvHxw, m);
}

void Heavy_WSTD_DLAY::cBinop_QMJhPL8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_hWLaIHGz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_hWLaIHGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Z9mj4Q3, HV_BINOP_DIVIDE, 0, m, &cBinop_6Z9mj4Q3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6Z9mj4Q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VJ6gyvSi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_DBqPXhuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WrtyIQtD_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_WrtyIQtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EMvEb4rO_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_ZczcmHP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_twXqXEeh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_YBkntfrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WAjpqeCg_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_d1zZdoBB, m);
}

void Heavy_WSTD_DLAY::cBinop_EMvEb4rO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TVxssTIG, m);
}

void Heavy_WSTD_DLAY::cMsg_twXqXEeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YBkntfrj_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WAjpqeCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iRW3LZbH, m);
}

void Heavy_WSTD_DLAY::cMsg_EZoRY5S8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RrRn8aT2_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_RrRn8aT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HW6OjTbY_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_5i9CPP9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4UpepWnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_srP0sr1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_17fe1xLc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uQvOSfCI, m);
}

void Heavy_WSTD_DLAY::cBinop_HW6OjTbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ydeartJN, m);
}

void Heavy_WSTD_DLAY::cMsg_4UpepWnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_srP0sr1f_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_17fe1xLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kKZm2kt4, m);
}

void Heavy_WSTD_DLAY::cVar_ZBYHNm81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzC1uMkg, HV_BINOP_MULTIPLY, 0, m, &cBinop_qzC1uMkg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_O6KJPiaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fu5Ip7Bs_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_fu5Ip7Bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gtogmrYU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_qzC1uMkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IotJ8fQe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JGS9Y04a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzC1uMkg, HV_BINOP_MULTIPLY, 1, m, &cBinop_qzC1uMkg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gtogmrYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JGS9Y04a_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IotJ8fQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_eTaqaVBJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_eTaqaVBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BuNEr3wv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_L52Uz3qS, m);
}

void Heavy_WSTD_DLAY::cBinop_BuNEr3wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QLbquDv6, m);
}

void Heavy_WSTD_DLAY::cVar_KgKEGpDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GoidQ0ll, HV_BINOP_MULTIPLY, 0, m, &cBinop_GoidQ0ll_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_luusglLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hWQA388D_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_hWQA388D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fNDA9CKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_GoidQ0ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_MusHYHWM_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_OEnmwjph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GoidQ0ll, HV_BINOP_MULTIPLY, 1, m, &cBinop_GoidQ0ll_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fNDA9CKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OEnmwjph_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MusHYHWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8BnD2di2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8BnD2di2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qeQYMUj6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_y0H5VaYA, m);
}

void Heavy_WSTD_DLAY::cBinop_qeQYMUj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yOfxnnr4, m);
}

void Heavy_WSTD_DLAY::cBinop_QNhRkQx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ES1YvYsz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ES1YvYsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ghM1FbHA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vBzP9m7T_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_IJ3pbPW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ERKmEHaS_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9FRcMDj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xqR7OZAX_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_xqR7OZAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZg6GTcs, HV_BINOP_DIVIDE, 1, m, &cBinop_xZg6GTcs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ghM1FbHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Gla0yEyE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Gla0yEyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wXUpDpJV, m);
}

void Heavy_WSTD_DLAY::cMsg_HMvZUGE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZvitxgX4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZvitxgX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QNhRkQx8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vBzP9m7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y47bT1Dn, m);
}

void Heavy_WSTD_DLAY::cBinop_ERKmEHaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_3yqYsIzQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3yqYsIzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZg6GTcs, HV_BINOP_DIVIDE, 0, m, &cBinop_xZg6GTcs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xZg6GTcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMvZUGE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_F6xEQwpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J80AX6Uy, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_QMHxhQco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hjn7rgUF, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Yn5FBTKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ySWsSxGi, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_sawggyIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RzzPelBD, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7X9VOOJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c64T5Ws9, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_DNCHdZKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_59fuyhND, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_US2OtYXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gDwKpKk9, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_uOetnZR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PDtuFEeu, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Ix1BRbIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l3G98zDC, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_dvG1H3fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8RbaKBNP, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_9yMyNS99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mAGaG013, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_vFbA9Jls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0mrRf87m, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_vWghqqlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sobx9kKH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_blr4T0Vl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_60u298xz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sobx9kKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vWghqqlp, 1, m, &cVar_vWghqqlp_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_oofkThFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_zjx8Mk4P, 0, m, &cVar_zjx8Mk4P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_3iRsHI3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_zjx8Mk4P, 0, m, &cVar_zjx8Mk4P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_tXC6ekTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3iRsHI3l, 0, m, &cIf_3iRsHI3l_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_j6B4xmOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oofkThFd, 0, m, &cIf_oofkThFd_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_tGKhVlpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VHXkuSZ8, HV_BINOP_DIVIDE, 0, m, &cBinop_VHXkuSZ8_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_8Za4uPpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q6gsXAeN, HV_BINOP_MULTIPLY, 1, m, &cBinop_q6gsXAeN_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_fYxEZy9L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vTFpLFNj, 0, m, &cSlice_vTFpLFNj_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4ETKl86C, 0, m, &cSlice_4ETKl86C_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8nZJX4Hi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YYT5Cm0z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_vTFpLFNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_mW28HXz1, 0, m, &cVar_mW28HXz1_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_mW28HXz1, 0, m, &cVar_mW28HXz1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_4ETKl86C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VLK2Hi8q, HV_BINOP_NEQ, 1, m, &cBinop_VLK2Hi8q_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_mW28HXz1, 1, m, &cVar_mW28HXz1_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VLK2Hi8q, HV_BINOP_NEQ, 1, m, &cBinop_VLK2Hi8q_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_mW28HXz1, 1, m, &cVar_mW28HXz1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_mW28HXz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_f0ruIhDw_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_pOyo1WRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lung1ivX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dxraL0Sp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_Lung1ivX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VLK2Hi8q, HV_BINOP_NEQ, 1, m, &cBinop_VLK2Hi8q_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_dxraL0Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mW28HXz1, 0, m, &cVar_mW28HXz1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VLK2Hi8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pOyo1WRh, 1, m, &cIf_pOyo1WRh_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_YYT5Cm0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pOyo1WRh, 0, m, &cIf_pOyo1WRh_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_8nZJX4Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VLK2Hi8q, HV_BINOP_NEQ, 0, m, &cBinop_VLK2Hi8q_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_pWxM1GeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7TZu4a5C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aKJZYTDJ_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_epUddCHz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XPLtbKD2_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5AtUoI2h_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvjSmLwQ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_POiNebAY_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KU989MX6_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ksHfOyy0_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JHQxtsOW_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8wxAjo8h_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_reRDRN8I_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OO4zK10t_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YESwyXQF_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YjvNS7kR_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KHTJaMO9_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_XPLtbKD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N3bqVkRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_5AtUoI2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O65eZVqB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_lvjSmLwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s83TW173_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_POiNebAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCkLMPTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_KU989MX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fUJnsi5u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ksHfOyy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xzxuvrHo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_JHQxtsOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_09vz6vOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_8wxAjo8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SFMUwv7P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_reRDRN8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uZLo7bJW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_OO4zK10t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7u5uuySo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_YESwyXQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8SBy4kvn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_YjvNS7kR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mMQ27kBo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_KHTJaMO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EUGqOyqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_VHXkuSZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q6gsXAeN, HV_BINOP_MULTIPLY, 0, m, &cBinop_q6gsXAeN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_q6gsXAeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fYxEZy9L_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_aKJZYTDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tGKhVlpm, 0, m, &cVar_tGKhVlpm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Za4uPpW, 0, m, &cVar_8Za4uPpW_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_7TZu4a5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VHXkuSZ8, HV_BINOP_DIVIDE, 1, m, &cBinop_VHXkuSZ8_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_u5wUqnec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Za4uPpW, 0, m, &cVar_8Za4uPpW_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JgrAKizA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tGKhVlpm, 0, m, &cVar_tGKhVlpm_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_N3bqVkRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_O65eZVqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_s83TW173_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BCkLMPTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fUJnsi5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_xzxuvrHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_09vz6vOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SFMUwv7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_uZLo7bJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_7u5uuySo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_8SBy4kvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mMQ27kBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_EUGqOyqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5wUqnec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgrAKizA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SIOTDAMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E5FKoG2B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_yJKT3QQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E5FKoG2B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_opa9CfJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dtcbEIVJ, 0, m, &cVar_dtcbEIVJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rcXpYWYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yUU7fBZ6, 0, m, &cVar_yUU7fBZ6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_O3kGmSjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JNGZBgOC, 0, m, &cVar_JNGZBgOC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_siiB8jq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E5FKoG2B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_WD2KNftw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E5FKoG2B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_f0ruIhDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j6B4xmOE, 0, m, &cVar_j6B4xmOE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_60u298xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IXynNOXM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gwbE6AXZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_blr4T0Vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CJ0cBy37_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2DXgYExN_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_2DXgYExN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tXC6ekTC, 0, m, &cVar_tXC6ekTC_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_CJ0cBy37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3iRsHI3l, 1, m, &cIf_3iRsHI3l_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_IXynNOXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oofkThFd, 1, m, &cIf_oofkThFd_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_gwbE6AXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j6B4xmOE, 0, m, &cVar_j6B4xmOE_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_jrr8r5C1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_opa9CfJb_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_BJCfu9uW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_rcXpYWYX_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_cnBMsFnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_O3kGmSjM_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ceir25yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tXC6ekTC, 0, m, &cVar_tXC6ekTC_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_qFRVqrcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ix1BRbIu_sendMessage(_c, 0, m);
  cMsg_dvG1H3fg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_BA3eYIue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9yMyNS99_sendMessage(_c, 0, m);
  cMsg_vFbA9Jls_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_wkAehL63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yijDsKfB_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_YyPzAwrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4kT9rPqR, 0, m, &cVar_4kT9rPqR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_taEwSAR8, 0, m, &cVar_taEwSAR8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4P7WSNZm, 0, m, &cVar_4P7WSNZm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qn3lBel5, 0, m, &cVar_qn3lBel5_sendMessage);
  cMsg_LHW4gAky_sendMessage(_c, 0, m);
  cMsg_HQH1shtg_sendMessage(_c, 0, m);
  cMsg_ZfDSug06_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZazRoCSy, 0, m, &cVar_ZazRoCSy_sendMessage);
  cMsg_yu5l5ayQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sF4r6GdH, 0, m, &cVar_sF4r6GdH_sendMessage);
  cMsg_lSjpFpSj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IOnFPqGx, 0, m, &cVar_IOnFPqGx_sendMessage);
  cMsg_O6KJPiaD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZBYHNm81, 0, m, &cVar_ZBYHNm81_sendMessage);
  cMsg_luusglLs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KgKEGpDp, 0, m, &cVar_KgKEGpDp_sendMessage);
  cMsg_9FRcMDj5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IJ3pbPW9, 0, m, &cVar_IJ3pbPW9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZczcmHP2, 0, m, &cVar_ZczcmHP2_sendMessage);
  cMsg_DBqPXhuz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5i9CPP9R, 0, m, &cVar_5i9CPP9R_sendMessage);
  cMsg_EZoRY5S8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_7504E8G7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sX2GswNK_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_tn2jKWGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vWghqqlp, 0, m, &cVar_vWghqqlp_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_sfmXnjQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pWxM1GeC, 0, m, &cVar_pWxM1GeC_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_U5TWXn7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_epUddCHz_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_hjn7rgUF, VOf(Bf0));
    __hv_line_f(&sLine_l3G98zDC, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_ohd4nWbZ, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_TVxssTIG, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_iRW3LZbH, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_d1zZdoBB, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_mVwqd7El, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_fbq0hCMJ, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_J80AX6Uy, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_ySWsSxGi, VOf(Bf0));
    __hv_line_f(&sLine_8RbaKBNP, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_EuhNEfv8, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_ydeartJN, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_kKZm2kt4, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_uQvOSfCI, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_WRto2vL2, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_aq1IkHN9, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_RzzPelBD, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_11HUoNk4, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_7SnxC9Tf, VIf(Bf0));
    __hv_varread_f(&sVarf_gX4iSwbg, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_VwLxucoN, VIf(Bf0));
    __hv_varread_f(&sVarf_hBqVWXQy, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_JQT9YG8i, VOf(Bf1));
    __hv_rpole_f(&sRPole_s1jK79zH, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_jKMgk0Pz, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_bs8Goliy, VOf(Bf1));
    __hv_rpole_f(&sRPole_ayi4HAxi, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_EsDjvHxw, VOf(Bf0));
    __hv_rpole_f(&sRPole_276uF66i, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_2YNvZGkb, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_UO3RqxHn, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_mAGaG013, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_59fuyhND, VOf(Bf0));
    __hv_varread_f(&sVarf_L52Uz3qS, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_QLbquDv6, VOf(Bf4));
    __hv_rpole_f(&sRPole_noRB4NxI, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_y0H5VaYA, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_yOfxnnr4, VOf(Bf4));
    __hv_rpole_f(&sRPole_lK3F8PJD, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_y47bT1Dn, VOf(Bf6));
    __hv_rpole_f(&sRPole_szo2iTR9, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_u0xBiZke, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wXUpDpJV, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_0mrRf87m, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_c64T5Ws9, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_11HUoNk4, VIf(Bf6));
    __hv_line_f(&sLine_PDtuFEeu, VOf(Bf6));
    __hv_line_f(&sLine_gDwKpKk9, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_gX4iSwbg, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
