/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvTable.h"
#include "HvSignalRPole.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvControlUnop.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvSignalTabread.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlBinop.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_yUU7fBZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zjx8Mk4P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JNGZBgOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dtcbEIVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_itWNQMrt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3uAbmTV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4kT9rPqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3IhSMKW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_E5FKoG2B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_d99uSVrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_taEwSAR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oy9WvWgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZV0FZbDa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AHNEiIiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4P7WSNZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XVpYyRbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yijDsKfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Olixbn8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9DNJr2vE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3jWcJ9Te_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ULSTQEIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yihntFjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_89jlauFb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XTBrUtZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UmY7qXgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ClLlSKpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EobqLmKC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9DM8ZQLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AbT35NSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sX2GswNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HXvudGpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3fIQhqA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JQIcyFWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JXin1KE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yiHq8r2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xcVre4RK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TrydeJvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HjoARtvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EVwYMesT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5OGvp0Ui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_o7TEUdTt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4ENVzwiO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qn3lBel5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tlGoLOz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LHW4gAky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YvZkDLL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tGYWYeWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VqCpZ0KV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wYWvfadb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_bG1tLDU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_p4iHiZ2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KKyiVJI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q0whguEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dCSTkk8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Nyaew0Mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b6q9ZfCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fDTHXcqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HQH1shtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HtaJKgzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vE14V7M6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_B0qMNFh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_28EwNnXi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_2fYW2b5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_IJ3t6TuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hQgOCEs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XMMJ7tys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vpuuRYbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VxQLbKIz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7bBALs6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CCHf3dDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZazRoCSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZfDSug06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_l2yD2UsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1qQqz5vR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u93SHa6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s4VdtDwH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZMFceQB4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UKJH3Pnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9gj5OuoM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sF4r6GdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yu5l5ayQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DVNVDyUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rMRAK0eD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dsUuSXMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mPIhQo8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xip2GUec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ogT564yX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QWYLxhQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xU83vxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fuSpLOlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IOnFPqGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lSjpFpSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VSMxaiJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1HYdndZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fDfDhlOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VJ6gyvSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HQPcqtBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J0nxmXb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QMJhPL8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hWLaIHGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Z9mj4Q3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DBqPXhuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WrtyIQtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZczcmHP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YBkntfrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EMvEb4rO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_twXqXEeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WAjpqeCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EZoRY5S8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RrRn8aT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5i9CPP9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_srP0sr1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HW6OjTbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4UpepWnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_17fe1xLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZBYHNm81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O6KJPiaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fu5Ip7Bs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qzC1uMkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JGS9Y04a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gtogmrYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IotJ8fQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eTaqaVBJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BuNEr3wv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KgKEGpDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_luusglLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hWQA388D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GoidQ0ll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OEnmwjph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fNDA9CKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MusHYHWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8BnD2di2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qeQYMUj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QNhRkQx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ES1YvYsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IJ3pbPW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9FRcMDj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xqR7OZAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ghM1FbHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gla0yEyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HMvZUGE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZvitxgX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vBzP9m7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ERKmEHaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3yqYsIzQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZg6GTcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F6xEQwpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QMHxhQco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yn5FBTKL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sawggyIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7X9VOOJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DNCHdZKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_US2OtYXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uOetnZR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ix1BRbIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dvG1H3fg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9yMyNS99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vFbA9Jls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vWghqqlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sobx9kKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oofkThFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3iRsHI3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tXC6ekTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j6B4xmOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tGKhVlpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8Za4uPpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fYxEZy9L_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vTFpLFNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_4ETKl86C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mW28HXz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pOyo1WRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lung1ivX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dxraL0Sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VLK2Hi8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YYT5Cm0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8nZJX4Hi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pWxM1GeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_epUddCHz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_XPLtbKD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5AtUoI2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lvjSmLwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_POiNebAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KU989MX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ksHfOyy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JHQxtsOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8wxAjo8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_reRDRN8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OO4zK10t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YESwyXQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YjvNS7kR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KHTJaMO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VHXkuSZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q6gsXAeN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aKJZYTDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7TZu4a5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u5wUqnec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JgrAKizA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N3bqVkRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O65eZVqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s83TW173_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCkLMPTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fUJnsi5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzxuvrHo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_09vz6vOl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFMUwv7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uZLo7bJW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7u5uuySo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8SBy4kvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mMQ27kBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EUGqOyqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SIOTDAMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yJKT3QQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_opa9CfJb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rcXpYWYX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O3kGmSjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_siiB8jq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WD2KNftw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f0ruIhDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_60u298xz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_blr4T0Vl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2DXgYExN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CJ0cBy37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IXynNOXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gwbE6AXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jrr8r5C1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BJCfu9uW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cnBMsFnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ceir25yS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qFRVqrcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BA3eYIue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wkAehL63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YyPzAwrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7504E8G7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tn2jKWGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sfmXnjQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U5TWXn7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_hjn7rgUF;
  SignalLine sLine_l3G98zDC;
  SignalTabhead sTabhead_ohd4nWbZ;
  SignalTabread sTabread_mVwqd7El;
  SignalTabread sTabread_fbq0hCMJ;
  SignalLine sLine_J80AX6Uy;
  SignalLine sLine_ySWsSxGi;
  SignalLine sLine_8RbaKBNP;
  SignalTabhead sTabhead_EuhNEfv8;
  SignalTabread sTabread_WRto2vL2;
  SignalTabread sTabread_aq1IkHN9;
  SignalLine sLine_RzzPelBD;
  SignalTabwrite sTabwrite_7SnxC9Tf;
  SignalTabwrite sTabwrite_VwLxucoN;
  SignalRPole sRPole_s1jK79zH;
  SignalRPole sRPole_ayi4HAxi;
  SignalRPole sRPole_276uF66i;
  SignalDel1 sDel1_2YNvZGkb;
  SignalLine sLine_mAGaG013;
  SignalLine sLine_59fuyhND;
  SignalRPole sRPole_noRB4NxI;
  SignalRPole sRPole_lK3F8PJD;
  SignalRPole sRPole_szo2iTR9;
  SignalDel1 sDel1_u0xBiZke;
  SignalLine sLine_0mrRf87m;
  SignalLine sLine_c64T5Ws9;
  SignalLine sLine_PDtuFEeu;
  SignalLine sLine_gDwKpKk9;
  ControlVar cVar_yUU7fBZ6;
  ControlVar cVar_zjx8Mk4P;
  ControlVar cVar_JNGZBgOC;
  ControlVar cVar_dtcbEIVJ;
  ControlSlice cSlice_3uAbmTV1;
  ControlVar cVar_4kT9rPqR;
  ControlSlice cSlice_d99uSVrb;
  ControlVar cVar_taEwSAR8;
  ControlSlice cSlice_AHNEiIiZ;
  ControlVar cVar_4P7WSNZm;
  ControlBinop cBinop_yijDsKfB;
  ControlBinop cBinop_Olixbn8K;
  ControlBinop cBinop_ULSTQEIW;
  ControlBinop cBinop_yihntFjy;
  ControlBinop cBinop_UmY7qXgO;
  ControlBinop cBinop_EobqLmKC;
  ControlBinop cBinop_9DM8ZQLp;
  ControlBinop cBinop_AbT35NSi;
  ControlBinop cBinop_sX2GswNK;
  ControlBinop cBinop_HXvudGpX;
  ControlBinop cBinop_3fIQhqA9;
  ControlBinop cBinop_JQIcyFWn;
  ControlBinop cBinop_xcVre4RK;
  ControlBinop cBinop_HjoARtvJ;
  ControlBinop cBinop_EVwYMesT;
  ControlBinop cBinop_5OGvp0Ui;
  ControlSlice cSlice_4ENVzwiO;
  ControlVar cVar_qn3lBel5;
  ControlDelay cDelay_tGYWYeWo;
  ControlDelay cDelay_VqCpZ0KV;
  ControlBinop cBinop_bG1tLDU7;
  HvTable hTable_p4iHiZ2o;
  ControlBinop cBinop_Q0whguEV;
  ControlDelay cDelay_vE14V7M6;
  ControlDelay cDelay_B0qMNFh7;
  ControlBinop cBinop_2fYW2b5A;
  HvTable hTable_IJ3t6TuL;
  ControlBinop cBinop_XMMJ7tys;
  ControlVar cVar_ZazRoCSy;
  ControlBinop cBinop_1qQqz5vR;
  ControlBinop cBinop_u93SHa6T;
  SignalVarf sVarf_JQT9YG8i;
  ControlBinop cBinop_ZMFceQB4;
  ControlBinop cBinop_UKJH3Pnp;
  ControlBinop cBinop_9gj5OuoM;
  SignalVarf sVarf_hBqVWXQy;
  ControlVar cVar_sF4r6GdH;
  ControlBinop cBinop_rMRAK0eD;
  ControlBinop cBinop_dsUuSXMP;
  SignalVarf sVarf_bs8Goliy;
  ControlBinop cBinop_Xip2GUec;
  ControlBinop cBinop_ogT564yX;
  ControlBinop cBinop_QWYLxhQw;
  SignalVarf sVarf_jKMgk0Pz;
  ControlBinop cBinop_9xU83vxV;
  ControlBinop cBinop_fuSpLOlu;
  SignalVarf sVarf_EsDjvHxw;
  ControlVar cVar_IOnFPqGx;
  ControlBinop cBinop_1HYdndZx;
  ControlBinop cBinop_fDfDhlOf;
  ControlBinop cBinop_HQPcqtBZ;
  ControlBinop cBinop_J0nxmXb8;
  ControlBinop cBinop_QMJhPL8a;
  ControlBinop cBinop_hWLaIHGz;
  ControlBinop cBinop_6Z9mj4Q3;
  SignalVarf sVarf_UO3RqxHn;
  ControlVar cVar_ZczcmHP2;
  ControlBinop cBinop_EMvEb4rO;
  ControlBinop cBinop_WAjpqeCg;
  SignalVarf sVarf_d1zZdoBB;
  SignalVarf sVarf_TVxssTIG;
  SignalVarf sVarf_iRW3LZbH;
  ControlVar cVar_5i9CPP9R;
  ControlBinop cBinop_HW6OjTbY;
  ControlBinop cBinop_17fe1xLc;
  SignalVarf sVarf_uQvOSfCI;
  SignalVarf sVarf_ydeartJN;
  SignalVarf sVarf_kKZm2kt4;
  ControlVar cVar_ZBYHNm81;
  ControlBinop cBinop_qzC1uMkg;
  ControlBinop cBinop_JGS9Y04a;
  SignalVarf sVarf_QLbquDv6;
  ControlBinop cBinop_IotJ8fQe;
  ControlBinop cBinop_eTaqaVBJ;
  ControlBinop cBinop_BuNEr3wv;
  SignalVarf sVarf_L52Uz3qS;
  ControlVar cVar_KgKEGpDp;
  ControlBinop cBinop_GoidQ0ll;
  ControlBinop cBinop_OEnmwjph;
  SignalVarf sVarf_yOfxnnr4;
  ControlBinop cBinop_MusHYHWM;
  ControlBinop cBinop_8BnD2di2;
  ControlBinop cBinop_qeQYMUj6;
  SignalVarf sVarf_y0H5VaYA;
  ControlBinop cBinop_QNhRkQx8;
  ControlBinop cBinop_ES1YvYsz;
  SignalVarf sVarf_y47bT1Dn;
  ControlVar cVar_IJ3pbPW9;
  ControlBinop cBinop_ghM1FbHA;
  ControlBinop cBinop_Gla0yEyE;
  ControlBinop cBinop_ZvitxgX4;
  ControlBinop cBinop_vBzP9m7T;
  ControlBinop cBinop_ERKmEHaS;
  ControlBinop cBinop_3yqYsIzQ;
  ControlBinop cBinop_xZg6GTcs;
  SignalVarf sVarf_wXUpDpJV;
  SignalVarf sVarf_11HUoNk4;
  SignalVarf sVarf_gX4iSwbg;
  ControlVar cVar_vWghqqlp;
  ControlBinop cBinop_sobx9kKH;
  ControlIf cIf_oofkThFd;
  ControlIf cIf_3iRsHI3l;
  ControlVar cVar_tXC6ekTC;
  ControlVar cVar_j6B4xmOE;
  ControlVar cVar_tGKhVlpm;
  ControlVar cVar_8Za4uPpW;
  ControlSlice cSlice_vTFpLFNj;
  ControlSlice cSlice_4ETKl86C;
  ControlVar cVar_mW28HXz1;
  ControlIf cIf_pOyo1WRh;
  ControlBinop cBinop_VLK2Hi8q;
  ControlVar cVar_pWxM1GeC;
  ControlBinop cBinop_VHXkuSZ8;
  ControlBinop cBinop_q6gsXAeN;
  ControlBinop cBinop_opa9CfJb;
  ControlBinop cBinop_rcXpYWYX;
  ControlBinop cBinop_O3kGmSjM;
  ControlBinop cBinop_f0ruIhDw;
  ControlBinop cBinop_60u298xz;
  ControlBinop cBinop_blr4T0Vl;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
